TokenAccountingTotals

Struct TokenAccountingTotals 

pub struct TokenAccountingTotals {
    pub measured_tokens_saved: i128,
    pub gross_modeled_tokens_avoided: i128,
    pub deduped_modeled_tokens_avoided: i128,
    pub repeated_baselines_deduped: u128,
    pub observed_file_read_replacements: u128,
    pub modeled_file_reads_avoided: u128,
}
Wide separated accounting totals before narrowing to the public report representation.

Fields

measured_tokens_saved: i128

Observed before/after saved tokens.

gross_modeled_tokens_avoided: i128

Gross modeled avoided tokens before baseline deduplication.

deduped_modeled_tokens_avoided: i128

Modeled avoided tokens after runtime-instance baseline deduplication.

repeated_baselines_deduped: u128

Number of repeated modeled baseline calls collapsed by deduplication.

observed_file_read_replacements: u128

Observed calls that replaced a whole-file read.

modeled_file_reads_avoided: u128

Modeled navigation calls that likely avoided a whole-file read.